class Commands:
    SAY        = "say"
    TELL       = "tell"
    KICK       = "clientkick_for_reason"
    
    GET_INFO   = "getinfo"
    GET_STATUS = "getstatus"
    STATUS     = "status"
    
    RESPONSE      = "print"
    INFO_RESPONSE = "infoResponse"

    GET_DVAR = "rcon"
    SET_DVAR = "rcon"

class Colors:
    DBLUE  = "^0"
    RED    = "^1"
    GREEN  = "^2"
    YELLOW = "^3"
    BLUE   = "^4"
    LBLUE  = "^5"
    PURPLE = "^6"
    WHITE  = "^7"
    GRAY   = "^8"
    BROWN  = "^9"
    BLINK  = "^F"